@@ -3,10 +3,10 @@
 mice_imputation_pls_pca_reduction <- function(x , pcamaxcols ,
 	pls.print.progress)
 {						
-	if ( base::ncol(x) > pcamaxcols ){
-	    a0 <- base::Sys.time()
-		NX <- base::nrow(x)
-		xdims <- base::min( pcamaxcols , NX-2 )
+	if ( ncol(x) > pcamaxcols ){
+	    a0 <- Sys.time()
+		NX <- nrow(x)
+		xdims <- min( pcamaxcols , NX-2 )
 		if( pls.print.progress ){ 
 			cat("\nDimension reduction with Principal Components Analysis\n")
 			if (pcamaxcols > 1){
@@ -18,11 +18,11 @@ mice_imputation_pls_pca_reduction <- function(x , pcamaxcols ,
 						100 * pcamaxcols , "% of total variance\n")
 			}
 		}				
-		x <- base::as.matrix(x)
+		x <- as.matrix(x)
 		xpca <- pca.covridge(x=x)
 		varexpl <- xpca$sdev^2 
-		varexpl <- base::cumsum( varexpl / base::sum( varexpl) * 100 )
-		xdims <- base::which( varexpl > 100*pcamaxcols )[1]
+		varexpl <- cumsum( varexpl / sum( varexpl) * 100 )
+		xdims <- which( varexpl > 100*pcamaxcols )[1]
 		if (pls.print.progress){
 			cat( " ->" , xdims , "extracted dimensions\n")
 			cat("Explained variance:" , round( varexpl[ xdims] , 2 )  , " % " )
@@ -34,5 +34,5 @@ mice_imputation_pls_pca_reduction <- function(x , pcamaxcols ,
 		}
 	}			
 	#--- output
-	base::return(x)
+	return(x)
 }
