@@ -1,5 +1,5 @@
 
 sd0 <- function(x, na.rm=TRUE){
 	sd1 <- stats0( x = x , FUN = stats::sd , na.rm=na.rm )
-	base::return(sd1)
-}
\ No newline at end of file
+	return(sd1)
+}
