@@ -13,6 +13,15 @@ subset_datlist <- function( datlist , subset = TRUE ,
 			datlist <- mids2datlist( datlist )
 									}		
 		
+		#*****************************
+		# check for subset if numeric
+		if ( ! is.null(subset) ){			
+			if ( is.integer(subset) ){
+				N <- nrow(datlist[[1]])
+				subset <- ( 1:N ) %in% subset
+							}			
+					}
+		
 		#*****************************
 		# check for expr
 		expr <- expr_subset 
